#
# spec file for package retext
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           retext
Version:        8.0.2
Release:        1.4
Summary:        Simple editor for Markdown and reStructuredText
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            https://github.com/retext-project/retext
Source:         https://github.com/retext-project/retext/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3
BuildRequires:  python3-Markdown
BuildRequires:  python3-Markups >= 2.0
BuildRequires:  python3-PyQt6
BuildRequires:  python3-devel
BuildRequires:  python3-docutils
BuildRequires:  python3-setuptools
%if 0%{suse_version} >= 1550 || 0%{?sle_version} >= 150200
BuildRequires:  rsvg-convert
%else
BuildRequires:  rsvg-view
%endif
BuildRequires:  update-desktop-files
Requires:       python3-Markdown
Requires:       python3-Markups >= 2.0
Requires:       python3-Pygments
Requires:       python3-docutils
Requires:       python3-qt6
Recommends:     python3-PyQt6-WebEngine
Recommends:     python3-chardet
Recommends:     python3-pyenchant
Provides:       ReText = %{version}
BuildArch:      noarch

%description
ReText is simple text editor that supports Markdown and reStructuredText
markup languages. It is written in Python using PyQt libraries.

%prep
%autosetup
dos2unix LICENSE_GPL
# remove shebang
sed -i '/^#!/d' ReText/__main__.py ReText/converterprocess.py

%build
%python3_build

%install
%python3_install

mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
mkdir -pv %{buildroot}%{_datadir}/%{name}/
mkdir -pv %{buildroot}%{_datadir}/applications/

cp -r ReText/icons/*.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ICONSIZE="16 22 32 48 64 128 256"
pushd %{buildroot}%{_datadir}/icons/hicolor/
for i in $ICONSIZE; do
  mkdir -pv ${i}x${i}/apps/
  rsvg-convert -h $i -w $i scalable/apps/%{name}.svg -o ${i}x${i}/apps/%{name}.png
done
popd

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/me.mitya57.ReText.desktop

%fdupes -s %{buildroot}%{_prefix}

%files
%doc changelog.md README.md configuration.md
%license LICENSE_GPL
%{_bindir}/%{name}
%{python3_sitelib}/ReText/
%{python3_sitelib}/*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*appdata.xml

%changelog
* Tue Mar 26 2024 Gordon Leung <pirateclip@protonmail.com>
- Update to version 8.0.2:
  * Added Apply button to Preferences dialogs.
  * Save button is now enabled in auto-save mode.
  * Support spell checking for multiple languages.
  * Support setting bold font for editor.
  * Added backtick key to surround keys.
  * Fix opening files in existing window by relative path.
  * Fix unreachable text at the bottom of the file.
  * Fix truncating file when new text cannot be encoded with
    the selected encoding.
  * Allow WebEngine renderer to load iframes such as YouTube embeds.
  * Fix incorrect font size with WebEngine renderer.
  * LICENSE_GPL file now has text of GPL v2.
  * Fixed synchronized scrolling for zoom factors other than 1.
  * Stopped passing .desktop suffix to setDesktopFileName().
  * Made mdx_posmap not break indented code blocks which use
    pymdownx.superfences extension.
  * Fixed crash when clicking on line information area.
  * Translations have been updated
* Thu Sep  8 2022 Fabian Vogt <fvogt@suse.com>
- Update to version 7.2.3:
  * Fixed TypeError crash with Python 3.10 and Qt WebKit.
  * Translations updated:
    + Chinese (China) (contributed by liulitchi).
    + Portuguese (Brazil) (contributed by Igor Garcia and Christiano Morais).
    + Slovak (contributed by Jose Riha).
- Update to version 7.2.2:
  * Fixed bad Spanish translation causing a crash.
  * Fixed "TypeError: index 0 has type 'float' but 'int' is expected"
    with Python 3.10.
  * Fixed "RuntimeError: ffi_prep_cif_var failed" in XSettings code.
* Tue Mar 16 2021 Matthias Mailänder <mailaender@opensuse.org>
- Update to version 7.2.1
- Recommend PyQtWebEngine for JavaScript support
* Fri May 22 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.1.0
  General improvements:
  * New files are now opened in new tabs by default, not new
    windows.
  * Preferences dialog improvements: it now uses tabs.
  * Return key now automatically continues quote blocks and
    ordered lists
  * It is now possible to close the current tab with Ctrl+W
  * Ctrl+wheel on editor now increases/decreases font size.
    Ctrl+wheel in preview zooms in/out.
  * Alt+Up/Down arrow now moves the current line up/down.
  * Added “Jump to Line” feature, with Ctrl+G shortcut.
  * Table mode improvements.
  * “Paste Image” moved to a separate action, with Ctrl+Shift+V
    shortcut.
  * Added “Insert table” dialog.
  * Clicking a link to nonexistent file now prompts the user to
    create it.
  * Added a menu action to insert images from filesystem.
  New options added:
  * `relativeLineNumbers` — count line numbers as relative to
    the current line.
  * `documentStatsEnabled` — show text statistics in the lower
    left corner of the editor.
  * `rightMarginWrap` — soft-wrap text at user specified margin
    line.
  * `paperSize` — set the default paper size for print or PDF
    export.
  * `recentDocumentsCount` — number of recent files to show in
    the menu.
  * `windowTitleFullPath` — show full path in window title
  * `defaultPreviewState` — mode for new tabs: `editor`,
    `normal-preview` or `live-preview`.
  * `wideCursor` — make cursor as wide as characters.
  Bugs fixed:
  * Limit max-width of images to 100%%.
  * setup.py now installs retext.svg icon.
  * Autofill current filename for PDF export and Save As dialogs.
  * Make sure search result does not overlap with stats/info
    areas.
  * Made the Markdown include extension working.
  * Fixed handling multi-line rows in reStructuredText tables in
    table mode.
  * Ctrl+F now focuses the search field, not closes the search
    bar. To close the search bar, now the Escape key can be used.
  * Ensure that cursor is visible after resizes.
  * Only check whether .css file exists on initial page load.
  * Try to load libGL.so.1 before creating QApplication.
  * Fix printing with dark themes.
  * Make the WebKit renderer use disk cache.
  * AppData file improvements.
  * Files reloading no longer triggers tab change.
  * Implemented PDF export for the WebEngine renderer.
  * Make the highlighter not break the pymdownx.highlight
    extension.
  * WebEngine renderer broken with new Qt versions.
  * Include the stylesheet in exported HTML.
  * Display `*` in tab title when document is modified and
    unsaved.
  * Enable HiDPI icons.
  * Updated Chinese (China), Czech, Danish, Dutch, Finnish,
    German, Italian, Korean, Portuguese (Brazil),  Portuguese
    (European), Russian, Serbian, Spanish, Swedish and Ukrainian
    translations
- Spec cleanup
* Thu Feb 20 2020 Max Lin <mlin@suse.com>
- Leap 15.2 and SLE15 SP2 has newer librsvg, extend the conditional
  for "BuildRequires: rsvg-convert"
* Wed Oct 23 2019 ro@suse.de
- fix build-requires for factory/tumbleweed
  rsvg-convert tool is now in rsvg-convert package
* Wed Jan  2 2019 badshah400@gmail.com
- Update to version 7.0.4:
  * Improved editor performance (gh#retext-project/retext#360).
  * Support for Python-Markdown 3.0.
  * Updated translations.
* Tue Oct  2 2018 Marguerite Su <i@marguerite.su>
- Update to version 7.0.0
  * The highlighter was improved. It got support for
    reStructuredText links, field lists and for Markdown and
    reStructuredText code spans.
  * Added the text replace feature.
  * Added the experimental renderer based on Qt WebEngine, in
    addition to the existing Qt WebKit one.
  * It is now possible to insert new table rows by pressing Return
    in "Table editing mode". Additionally, pressing Shift+Return
    will create a new row and a separator line
  * The WebKit and WebEngine previewers can now detect links
    to local HTML files and open the corresponding source file
    in new tab if those are found.
  * ReText can now automatically detect encoding of files using
    the chardet module when it is installed.
  * Several new configuration options were added.
- upstream fixed boo#1040433
  * ReText can't start from KDE Application launcher (kickoff)
    but can from command line because sys.stdin.read() led
    to a blockage
- drop retext-add-appdata-description.patch, upstreamed
* Tue Jan 10 2017 mpluskal@suse.com
- Fix typo in patch
* Sat Jan  7 2017 badshah400@gmail.com
- Add retext-add-appdata-description.patch to add a helpful
  description to the appdata file; changes taken from upstream.
* Sat May 14 2016 mpluskal@suse.com
- Update to version 6.0.0
  * The live preview now automatically scrolls to match its
    sition with the editor (only for Markdown).
  * Markup conversion is now performed in a background process,
    proving responsiveness of the editor.
  * Images can now be copied and pasted into ReText (contributed by
    Bart Clephas).
  * Added a button to quickly close the search bar.
  * Added basic CSS styling for tables.
  * Replaced the tags box with the new “Formatting” box for
    Markdown (contributed by Donato Marrazzo).
  * Hitting return twice now ends the Markdown list.
  * ReText now depends on version 2.0 or higher of pymarkups.
  * The QtWebKit dependency is now optional (though still
    recommended).
- Spec file cleanups
  * Update dependencies
  * Use pretty name for source archive
  * Disable testsuite as it requires connection to Xserver
* Mon Dec 21 2015 badshah400@gmail.com
- Update to version 5.3.0:
  + Tabs are now reorderable.
  + All colors used in editor and highlighter are now configurable
    via the configuration file.
  + Links referencing other source files are now opened in ReText
    as new tabs.
  + Code refactoring: some code moved to the new tab.py module,
    and some old hacks dropped.
  + The ReText logo is now installed to the data directory.
  + Appstream metadata updated to a newer format.
  + The desktop file no longer hardcodes the executable path.
- Changes from version 5.2.0:
  + ReText now tries to load the icon theme from system settings
    if Qt cannot auto-detect it.
  + Added a GUI option to change the editor font.
  + Added appdata file for appstream.
- Drop custom desktop file and use upstream bundled file.
- Package appdata.
- Add post(un) scriptlets for updating icon theme cache and
  desktop database.
- Project moved to github, update URL and source location
  accordingly.
* Tue Jun 30 2015 mailaender@opensuse.org
- update to version 5.1.0
- enable test suite
* Mon Jun  8 2015 mailaender@opensuse.org
- update to version 5.0.2
* Tue Jan  6 2015 kinfoo.dev@gmail.com
- recommend Python Pygments for syntax highlight
* Fri Dec 19 2014 mailaender@opensuse.org
- update to version 5.0.1
* Sat Jul 26 2014 mailaender@opensuse.org
- update to version 5.0.0
* Sat Jun 14 2014 mailaender@opensuse.org
- update to version 4.1.3
* Wed Apr 16 2014 mailaender@opensuse.org
- update version 4.1.2
- added GPG file verification
* Sat Sep 21 2013 mailaender@opensuse.org
- update version 4.1.1
  * Added configuration dialog
  * Added current line highlighting and line numbers support
  * Added support for PyQt5 and PySide libraries
  * Use new signals/slots syntax
  * Added option to select file encoding
  * Dropped support for Python 2 and support for running
    without WebKit installed
- adhere to https://en.opensuse.org/SourceUrls
* Sun Feb 24 2013 i@marguerite.su
- add link to %%{_bindir}/%%{name}
- correct dependency name python-Markups
* Sat Feb  2 2013 i@marguerite.su
- update version 4.0.0
  * Switch to pymarkups backend
  * Switch to python3 by default
  * Split retext.py to smaller files
  * MathJax support
  * Tab now inserts 4 spaces by default
  * Automatic indentation of new lines
  * External links are now opened in a web browser by default
  * Support for per-document CSS stylesheets
* Tue Jul 31 2012 i@marguerite.su
- update version 3.1.0
  * Spell checker suggestions
  * Markup-specifing highlighting
  * Re-written parser & document-type logic
  * Lots of code clean-up
* Mon May 21 2012 i@marguerite.su
- update to 3.0.3
  * Python 3 support
  * Improved highlighter
  * Export extensions
  * Recent files menu
  * Spell checking improvements
  * Shortcuts for formatting
  * WebKit engine improvements
* Sat Feb 18 2012 i@marguerite.su
- update to 3.0beta1
* Thu Dec 29 2011 i@marguerite.su
- update to 2.1.3
* Fri Nov 25 2011 pascal.bleser@opensuse.org
- initial version (2.1.2)
